"""Commong stuff for I/O"""

from collections import namedtuple

IOResult = namedtuple("IOResult", ["data", "metadata"])
